API docs for “spamfighter.txjsonrpc.web.jsonrpc”

# Module s.t.w.jsonrpc

Part of spamfighter.txjsonrpc.web View Source

A generic resource for publishing objects via JSON-RPC.

Requires simplejson; can be downloaded from http://cheeseshop.python.org/pypi/simplejson

API Stability: unstable

Maintainer: Duncan McGreggor

Class | NoSuchFunction | There is no function by the given name.
Class | Handler | Handle a JSON-RPC request and store the state for a request in progress.
Class | JSONRPC | A resource that implements JSON-RPC.
Class | JSONRPCIntrospection | Implement a JSON-RPC Introspection API.
Function | addIntrospection | Add Introspection support to an JSONRPC server.
Class | QueryProtocol | Undocumented
Class | QueryFactory | Undocumented
Class | Proxy | A Proxy for making remote JSON-RPC calls.

def addIntrospection(jsonrpc): (source)
Add Introspection support to an JSONRPC server.

Parameters | jsonrpc | The jsonrpc server to add Introspection support to.